#' @keywords internal
"_PACKAGE"

utils::globalVariables(c(
  "balance_sheet_category", "series", "risk_metric_category",
  "sheet_details", "sheet", "data_type", "series_hierarchy",
  "unit", "value", "error", "local_format_id", "statistics_publication_name",
  "indent", "measure_type", "stat_pub_acronym", "count"
))
